@@ -125,6 +125,8 @@ QString ChatTextItem::createHTML()
             html.append(CHECK);
         else if (message.status == FMessage::ReceivedByTarget)
            html.append(DOUBLECHECK);
+        else if (message.status == FMessage::ReadByTarget)
+           html.append(DOUBLEBLUECHECK);
         else
            html.append(GRAYCHECK);
     }
