@@ -1947,7 +1947,7 @@ void Connection::sendPaused(FMessage message)
     @param subject  Group name or subject.
     @param id       Id of the request.
 */
-void Connection::sendCreateGroupChat(QString subject, QString id)
+void Connection::sendCreateGroupChat(QString subject, QString id, QStringList participants)
 {
     ProtocolTreeNode groupNode("create");
 
@@ -1955,6 +1955,15 @@ void Connection::sendCreateGroupChat(QString subject, QString id)
     attrs.insert("subject", subject);
     groupNode.setAttributes(attrs);
 
+    foreach (QString jid, participants)
+    {
+        ProtocolTreeNode participantNode("participant");
+        AttributeList attrs;
+        attrs.insert("jid", jid);
+        participantNode.setAttributes(attrs);
+        groupNode.addChild(participantNode);
+    }
+
     ProtocolTreeNode iqNode("iq");
 
     attrs.clear();
